@@ -76,6 +76,11 @@ def main(argv: Optional[Sequence[str]] = None) -> None:
         dest="output_filename",
         help="Specify the file name of the media output. Default is the input video file name.",
     )
+    parent_parser.add_argument(
+        "--monochrome",
+        action="store_true",
+        help="Convert the media output to monochrome (black and white).",
+    )
     parent_parser.add_argument(
         "--quiet",
         action="store_true",
@@ -89,7 +94,7 @@ def main(argv: Optional[Sequence[str]] = None) -> None:
 
     # main parser and subparsers
     main_parser = argparse.ArgumentParser(
-        prog="vxt",
+        prog="videoxt",
         description="Extract individual frames from a video, or create a GIF between two points in a video.",
     )
     main_parser.add_argument(
