@@ -1,4 +1,3 @@
-import datetime
 import math
 import os
 from dataclasses import dataclass, field
@@ -28,6 +27,7 @@ class BaseVideoExtractor:
     rotate: int = 0
     output_dir: Optional[str] = None
     output_filename: Optional[str] = None
+    monochrome: bool = False
     quiet: bool = False
     emoji: bool = False
     extraction_type: str = field(init=False)
@@ -99,7 +99,7 @@ class BaseVideoExtractor:
     def _initialize_video_metadata(self) -> None:
         """Video metadata initialized: frame count, fps, video length, and video dimensions."""
         video_capture = cv2.VideoCapture(self.video_abspath)
-
+        print(video_capture.get(cv2.CAP_PROP_FRAME_COUNT))
         self.frame_count = round(video_capture.get(cv2.CAP_PROP_FRAME_COUNT), 2)
 
         if self.fps is None:
@@ -258,8 +258,8 @@ class BaseVideoExtractor:
               type:         {self.extraction_type!r}
               start time:   {start_time_display}
               stop time:    {stop_time_display}
-              start frame:  {self.start_frame + 1 if not self.emoji else C.EMOJI_MAP['start'] + ' ' + str(self.start_frame + 1)}
-              stop frame:   {self.stop_frame + 1 if not self.emoji else C.EMOJI_MAP['stop'] + ' ' + str(self.stop_frame + 1)}
+              start frame:  {self.start_frame if not self.emoji else C.EMOJI_MAP['start'] + ' ' + str(self.start_frame)}
+              stop frame:   {self.stop_frame if not self.emoji else C.EMOJI_MAP['stop'] + ' ' + str(self.stop_frame)}
               output dir:   {self.output_dir}"""
         )
 
@@ -295,6 +295,9 @@ class VideoToImages(BaseVideoExtractor):
         if self.rotate in C.ROTATION_MAP:
             image = cv2.rotate(image, C.ROTATION_MAP[self.rotate])
 
+        if self.monochrome:
+            image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
+
         return image
 
     def extract_images(self) -> None:
@@ -374,6 +377,7 @@ class VideoToImages(BaseVideoExtractor):
               format:       {self.image_format!r}
               resize:       {resize_display}
               rotate:       {rotate_display}
+              monochrome:   {self.monochrome}
               capture rate: {self.capture_rate}
               expected:     {self.images_expected}
               dimensions:   {self.target_dimensions}
@@ -403,6 +407,9 @@ class VideoToGIF(BaseVideoExtractor):
         if self.bounce:
             subclip = concatenate([subclip, subclip.fx(vfx.time_mirror)])
 
+        if self.monochrome:
+            subclip = subclip.fx(vfx.blackwhite)
+
         return subclip
 
     def create_gif(self) -> None:
@@ -454,6 +461,7 @@ class VideoToGIF(BaseVideoExtractor):
               filename:     {self.output_filename!r}
               resize:       {resize_display}
               rotate:       {rotate_display}
+              monochrome:   {self.monochrome}
               speed:        {speed_display}
               bounce:       {self.bounce}
               dimensions:   {self.target_dimensions}
