@@ -3,6 +3,10 @@ from typing import Union
 
 
 def timestamp_to_seconds(timestamp: str) -> int:
+    """Converts a timestamp string to seconds. Milliseconds are truncated."""
+    if "." in timestamp:
+        timestamp = timestamp.split(".")[0]
+
     if ":" in timestamp:
         seconds = 0
         for value in timestamp.split(":"):
@@ -14,6 +18,7 @@ def timestamp_to_seconds(timestamp: str) -> int:
 
 
 def seconds_to_timestamp(seconds: Union[float, int]) -> str:
+    """Converts seconds to a timestamp string. Milliseconds are truncated."""
     if isinstance(seconds, float):
         seconds = int(seconds)
     return str(datetime.timedelta(seconds=seconds))
